@@ -1,10 +1,13 @@
 #!/bin/bash
 set -e
 ## begin variables passed in by jenkins
-# export reference=$reference
 
 export PG_VER=9.6
+# export PGPORT=8442
 export OS_BUILD=64
+# export POSTGIS_MAJOR_VERSION=2
+# export POSTGIS_MINOR_VERSION=2
+# export POSTGIS_MICRO_VERSION=0dev
 export PROJECTS=/var/lib/jenkins/workspace
 export GEOS_VER=3.6
 export GDAL_VER=2.2
@@ -12,7 +15,6 @@ export WEB_DIR=/var/www/postgis_stuff
 export PATH="${PGPATH}/bin:$PATH"
 export LD_LIBRARY_PATH="${PROJECTS}/gdal/rel-${GDAL_VER}w${OS_BUILD}/lib:${PROJECTS}/geos/rel-${GEOS_VER}w${OS_BUILD}/lib:${PGPATH}/lib"
 
-echo "Reference Branch: $reference"
 POSTGIS_MAJOR_VERSION=`grep ^POSTGIS_MAJOR_VERSION Version.config | cut -d= -f2`
 POSTGIS_MINOR_VERSION=`grep ^POSTGIS_MINOR_VERSION Version.config | cut -d= -f2`
 POSTGIS_MICRO_VERSION=`grep ^POSTGIS_MICRO_VERSION Version.config | cut -d= -f2`
@@ -30,4 +32,4 @@ export package=${newoutdir}.tar.gz
 echo "The package name is $package"
 
 cp $package $WEB_DIR
-sh ci/debbie/postgis_release_docs.sh
+bash ci/debbie/postgis_release_docs.sh
