@@ -9,18 +9,18 @@
 #POSTGIS_MAJOR_VERSION=2
 #POSTGIS_MINOR_VERSION=1
 #POSTGIS_MICRO_VERSION=0dev
+#export OS_BUILD=32
+
+#export GCC_TYPE=
+export SFCGAL_VER=1.3.2
 export GEOS_VER=3.6.2
-export GDAL_VER=2.2.2
+export GDAL_VER=2.2.4
 export PROJ_VER=4.9.3
-export SFCGAL_VER=1.3
+export SFCGAL_VER=1.3.2
 export PCRE_VER=8.33
 export PROTOBUF_VER=3.2.0
 export PROTOBUFC_VER=1.2.1
-
-export PROTOBUF_VER=3.2.0
-export LIBXML_VER=2.7.8
-export PROTOBUF_VER=3.2.0
-export PROTOBUFC_VER=1.2.1
+export CGAL_VER=4.11
 
 if [[ "${GCC_TYPE}" == *gcc48* ]] ; then
 	export PROJECTS=/projects
@@ -54,15 +54,15 @@ export POSTGIS_MICRO_VER=${POSTGIS_MICRO_VERSION}
 
 if [[ "$POSTGIS_MICRO_VERSION"  == *SVN* || "$POSTGIS_MICRO_VERSION"  == *dev* ]] ; then
 	export POSTGIS_SRC=${PROJECTS}/postgis/branches/${POSTGIS_MINOR_VER}
-	export svnurl="http://svn.osgeo.org/postgis/branches/${POSTGIS_MINOR_VER}"
+	export svnurl="https://svn.osgeo.org/postgis/branches/${POSTGIS_MINOR_VER}"
 else
 	#tagged version -- official release
 	export POSTGIS_SRC=${PROJECTS}/postgis/tags/${POSTGIS_MINOR_VER}.${POSTGIS_MICRO_VERSION}
-	export svnurl="http://svn.osgeo.org/postgis/tags/${POSTGIS_MINOR_VER}.${POSTGIS_MICRO_VERSION}"
+	export svnurl="https://svn.osgeo.org/postgis/tags/${POSTGIS_MINOR_VER}.${POSTGIS_MICRO_VERSION}"
 fi;
 
-if [[ "$POSTGIS_MINOR_VER"  == 2.3 ]] ; then
-	export svnurl="http://svn.osgeo.org/postgis/trunk"
+if [[ "$reference"  == *trunk* ]] ; then
+	export svnurl="https://svn.osgeo.org/postgis/trunk"
 fi;
 #export POSTGIS_SRC=${PROJECTS}/postgis/trunk
 #POSTGIS_SVN_REVISION=will_be_passed_in_by_bot
@@ -146,7 +146,6 @@ fi;
 
 if [ -n "$SFCGAL_VER"  ]; then
 	## only copy cgal and sfcgal stuff if sfcgal is packaged
-	export CGAL_VER=4.6.1
 	export BOOST_VER=1.59.0
 	export BOOST_VER_WU=1_59_0
 	export GMP_VER=5.1.2
@@ -199,7 +198,9 @@ cp topology/topology_upgrade_*.sql ${RELDIR}/${RELVERDIR}/share/contrib/postgis-
 #cp topology/README* ${RELDIR}/${RELVERDIR}/share/contrib/postgis-${POSTGIS_MINOR_VER}
 #cp utils/* ${RELDIR}/${RELVERDIR}/utils
 #cp extras/* ${RELDIR}/${RELVERDIR}/share/contrib/postgis-${POSTGIS_MINOR_VER}/extras
-cp -r extensions/*/sql/* ${RELDIR}/${RELVERDIR}/share/extension
+cp ${PGPATH}/share/extension/postgis*${POSTGIS_MICRO_VER}.sql ${RELDIR}/${RELVERDIR}/share/extension
+cp ${PGPATH}/share/extension/postgis*${POSTGIS_MICRO_VER}next.sql ${RELDIR}/${RELVERDIR}/share/extension
+cp ${PGPATH}/share/extension/address_standardizer*${POSTGIS_MICRO_VER}.sql ${RELDIR}/${RELVERDIR}/share/extension
 cp -r extensions/*/*.control ${RELDIR}/${RELVERDIR}/share/extension
 cp -r extensions/*/*.dll ${RELDIR}/${RELVERDIR}/lib #only address_standardizer in theory has this
 #cp extensions/postgis_topology/sql/* ${RELDIR}/${RELVERDIR}/share/extension
