@@ -1,15 +1,29 @@
 /**********************************************************************
  *
  * PostGIS - Spatial Types for PostgreSQL
+ * http://postgis.net
  *
- * Copyright 2013 Sandro Santilli <strk@keybit.net>
+ * PostGIS is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * PostGIS is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with PostGIS.  If not, see <http://www.gnu.org/licenses/>.
+ *
+ **********************************************************************
+ *
+ * Copyright 2013 Sandro Santilli <strk@kbt.io>
  * Copyright 2011 Kashif Rasul <kashif.rasul@gmail.com>
  *
- * This is free software; you can redistribute and/or modify it under
- * the terms of the GNU General Public Licence. See the COPYING file.
- *
  **********************************************************************/
 
+
 #include <assert.h>
 #include "liblwgeom.h"
 #include "lwgeom_log.h"
@@ -17,13 +31,19 @@
 
 #if defined(HAVE_LIBJSON) || defined(HAVE_LIBJSON_C) /* --{ */
 
+#define JSON_C_VERSION_013 (13 << 8)
+
 #ifdef HAVE_LIBJSON_C
 #include <json-c/json.h>
+#if !defined(JSON_C_VERSION_NUM) || JSON_C_VERSION_NUM < JSON_C_VERSION_013
 #include <json-c/json_object_private.h>
+#endif
 #else
 #include <json/json.h>
+#if !defined(JSON_C_VERSION_NUM) || JSON_C_VERSION_NUM < JSON_C_VERSION_013
 #include <json/json_object_private.h>
 #endif
+#endif
 
 #ifndef JSON_C_VERSION
 /* Adds support for libjson < 0.10 */
@@ -98,7 +118,7 @@ parse_geojson_coord(json_object *poObj, int *hasz, POINTARRAY *pa)
 			geojson_lwerror("Too few ordinates in GeoJSON", 4);
 			return LW_FAILURE;
 		}
-		
+
 		/* Read X coordinate */
 		poObjCoord = json_object_array_get_idx( poObj, 0 );
 		pt.x = json_object_get_double( poObjCoord );
@@ -123,7 +143,7 @@ parse_geojson_coord(json_object *poObj, int *hasz, POINTARRAY *pa)
 			/* Initialize Z coordinate, if required */
 			if ( FLAGS_GET_Z(pa->flags) ) pt.z = 0.0;
 		}
-		else 
+		else
 		{
 			/* TODO: should we account for nSize > 3 ? */
 			/* more than 3 coordinates, we're just dropping dimensions here... */
@@ -152,12 +172,12 @@ parse_geojson_point(json_object *geojson, int *hasz, int root_srid)
 	LWDEBUGF(3, "parse_geojson_point called with root_srid = %d.", root_srid );
 
 	coords = findMemberByName( geojson, "coordinates" );
-	if ( ! coords ) 
+	if ( ! coords )
 	{
 		geojson_lwerror("Unable to find 'coordinates' in GeoJSON string", 4);
 		return NULL;
 	}
-	
+
 	pa = ptarray_construct_empty(1, 0, 1);
 	parse_geojson_coord(coords, hasz, pa);
 
@@ -177,7 +197,7 @@ parse_geojson_linestring(json_object *geojson, int *hasz, int root_srid)
 	LWDEBUG(2, "parse_geojson_linestring called.");
 
 	points = findMemberByName( geojson, "coordinates" );
-	if ( ! points ) 
+	if ( ! points )
 	{
 		geojson_lwerror("Unable to find 'coordinates' in GeoJSON string", 4);
 	return NULL;
@@ -212,7 +232,7 @@ parse_geojson_polygon(json_object *geojson, int *hasz, int root_srid)
 	int nRings = 0, nPoints = 0;
 
 	rings = findMemberByName( geojson, "coordinates" );
-	if ( ! rings ) 
+	if ( ! rings )
 	{
 		geojson_lwerror("Unable to find 'coordinates' in GeoJSON string", 4);
 		return NULL;
@@ -231,7 +251,7 @@ parse_geojson_polygon(json_object *geojson, int *hasz, int root_srid)
 	{
 		return (LWGEOM *)lwpoly_construct_empty(root_srid, 0, 0);
 	}
-	
+
 	for ( i = 0; i < nRings; i++ )
 	{
 		points = json_object_array_get_idx(rings, i);
@@ -241,13 +261,13 @@ parse_geojson_polygon(json_object *geojson, int *hasz, int root_srid)
 			return NULL;
 		}
 		nPoints = json_object_array_length(points);
-		
+
 		/* Skip empty rings */
 		if ( nPoints == 0 ) continue;
-		
+
 		if ( ! ppa )
 			ppa = (POINTARRAY**)lwalloc(sizeof(POINTARRAY*) * nRings);
-		
+
 		ppa[i] = ptarray_construct_empty(1, 0, 1);
 		for ( j = 0; j < nPoints; j++ )
 		{
@@ -255,12 +275,12 @@ parse_geojson_polygon(json_object *geojson, int *hasz, int root_srid)
 			coords = json_object_array_get_idx( points, j );
 			parse_geojson_coord(coords, hasz, ppa[i]);
 		}
-	}	
-	
+	}
+
 	/* All the rings were empty! */
 	if ( ! ppa )
 		return (LWGEOM *)lwpoly_construct_empty(root_srid, 0, 0);
-	
+
 	return (LWGEOM *) lwpoly_construct(root_srid, NULL, nRings, ppa);
 }
 
@@ -281,7 +301,7 @@ parse_geojson_multipoint(json_object *geojson, int *hasz, int root_srid)
 	}
 
 	poObjPoints = findMemberByName( geojson, "coordinates" );
-	if ( ! poObjPoints ) 
+	if ( ! poObjPoints )
 	{
 		geojson_lwerror("Unable to find 'coordinates' in GeoJSON string", 4);
 		return NULL;
@@ -324,7 +344,7 @@ parse_geojson_multilinestring(json_object *geojson, int *hasz, int root_srid)
 	}
 
 	poObjLines = findMemberByName( geojson, "coordinates" );
-	if ( ! poObjLines ) 
+	if ( ! poObjLines )
 	{
 		geojson_lwerror("Unable to find 'coordinates' in GeoJSON string", 4);
 		return NULL;
@@ -376,7 +396,7 @@ parse_geojson_multipolygon(json_object *geojson, int *hasz, int root_srid)
 	}
 
 	poObjPolys = findMemberByName( geojson, "coordinates" );
-	if ( ! poObjPolys ) 
+	if ( ! poObjPolys )
 	{
 		geojson_lwerror("Unable to find 'coordinates' in GeoJSON string", 4);
 		return NULL;
@@ -387,18 +407,18 @@ parse_geojson_multipolygon(json_object *geojson, int *hasz, int root_srid)
 		const int nPolys = json_object_array_length( poObjPolys );
 
 		for(i = 0; i < nPolys; ++i)
-		{			
+		{
 			json_object* poObjPoly = json_object_array_get_idx( poObjPolys, i );
 
 			if( json_type_array == json_object_get_type( poObjPoly ) )
 			{
 				LWPOLY *lwpoly = lwpoly_construct_empty(geom->srid, lwgeom_has_z(geom), lwgeom_has_m(geom));
 				int nRings = json_object_array_length( poObjPoly );
-				
+
 				for(j = 0; j < nRings; ++j)
 				{
 					json_object* points = json_object_array_get_idx( poObjPoly, j );
-					
+
 					if( json_type_array == json_object_get_type( points ) )
 					{
 
@@ -410,7 +430,7 @@ parse_geojson_multipolygon(json_object *geojson, int *hasz, int root_srid)
 							json_object* coords = json_object_array_get_idx( points, k );
 							parse_geojson_coord(coords, hasz, pa);
 						}
-						
+
 						lwpoly_add_ring(lwpoly, pa);
 					}
 				}
@@ -439,7 +459,7 @@ parse_geojson_geometrycollection(json_object *geojson, int *hasz, int root_srid)
 	}
 
 	poObjGeoms = findMemberByName( geojson, "geometries" );
-	if ( ! poObjGeoms ) 
+	if ( ! poObjGeoms )
 	{
 		geojson_lwerror("Unable to find 'geometries' in GeoJSON string", 4);
 		return NULL;
@@ -466,14 +486,14 @@ parse_geojson(json_object *geojson, int *hasz, int root_srid)
 	json_object* type = NULL;
 	const char* name;
 
-	if( NULL == geojson ) 
+	if( NULL == geojson )
 	{
 		geojson_lwerror("invalid GeoJSON representation", 2);
 		return NULL;
 	}
 
 	type = findMemberByName( geojson, "type" );
-	if( NULL == type ) 
+	if( NULL == type )
 	{
 		geojson_lwerror("unknown GeoJSON type", 3);
 		return NULL;
